@@ -1,9 +1,10 @@
 import statistics
+from typing import Optional
 
 from django.conf import settings
 from django.contrib import admin
 from django.db import models
-from django.db.models import Count
+from django.db.models import Count, Prefetch
 from django.db.models.functions import Lower
 from django.utils.html import format_html
 
@@ -31,6 +32,11 @@ from .models import (
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
 
+def lines_sorted_html(items: list) -> str:
+    """Format list into HTML with one item per line."""
+    return format_html("<br>".join(sorted(items, key=str.casefold)))
+
+
 class BaseFuelAlertAdmin(admin.ModelAdmin):
     list_display = ("config", "_owner", "structure")
     list_select_related = (
@@ -212,8 +218,8 @@ class NotificationAdmin(admin.ModelAdmin):
         "notif_type",
         "timestamp",
         "created",
-        "last_updated",
         "_webhooks",
+        "_structures",
         "_is_sent",
         "_is_timer_added",
     )
@@ -228,26 +234,45 @@ class NotificationAdmin(admin.ModelAdmin):
 
     def get_queryset(self, request):
         qs = super().get_queryset(request)
-        return qs.prefetch_related("owner__webhooks").select_related(
-            "owner", "owner__corporation", "sender"
-        )
+        return qs.prefetch_related(
+            "owner__webhooks",
+            "structures",
+            "structures__eve_solar_system",
+            "structures__eve_type",
+            "structures__eve_type__eve_group",
+            Prefetch(
+                "structures",
+                queryset=Structure.objects.filter(webhooks__isnull=False),
+                to_attr="structures_with_webhooks",
+            ),
+        ).select_related("owner", "owner__corporation", "sender")
 
     def _webhooks(self, obj):
         if not obj.can_be_rendered:
             return format_html("<i>N/A</i>")
-        names = sorted(
-            [
+        webhooks_qs = obj.owner.webhooks.all()
+        if obj.structures_with_webhooks:
+            webhooks_qs = Webhook.objects.none()
+            for structure in obj.structures_with_webhooks:
+                webhooks_qs |= structure.webhooks.all()
+        names = list(
+            {
                 webhook.name
-                for webhook in obj.owner.webhooks.all()
+                for webhook in webhooks_qs
                 if obj.notif_type in webhook.notification_types
-            ]
+            }
         )
-        if names:
-            return ", ".join(names)
-        else:
+        if not names:
             return format_html(
                 '<b><span style="color: orange">⚠ Not configured</span></b>'
             )
+        return lines_sorted_html(names)
+
+    def _structures(self, obj) -> Optional[list]:
+        if obj.is_structure_related:
+            structures = [str(structure) for structure in obj.structures.all()]
+            return lines_sorted_html(structures) if structures else "?"
+        return None
 
     def _is_sent(self, obj):
         value = obj.is_sent if obj.can_be_rendered else None
@@ -289,18 +314,28 @@ class NotificationAdmin(admin.ModelAdmin):
 
     @admin.display(description="Send selected notifications to configured webhooks")
     def send_to_configured_webhooks(self, request, queryset):
-        obj_pks = [obj.pk for obj in queryset if obj.can_be_rendered]
-        ignored_count = len([obj for obj in queryset if not obj.can_be_rendered])
-        tasks.send_notifications.delay(obj_pks)
-        message = (
-            f"Initiated sending of {len(obj_pks)} notification(s) to "
-            f"configured webhooks."
-        )
+        obj_pks = [
+            obj.pk
+            for obj in queryset
+            if obj.can_be_rendered and obj.relevant_webhooks().exists()
+        ]
+        total_count = queryset.count()
+        ignored_count = total_count - len(obj_pks)
+        if obj_pks:
+            tasks.send_notifications.delay(obj_pks)
+            message = (
+                f"Initiated sending of {len(obj_pks)} notification(s) to "
+                f"configured webhooks."
+            )
+            level = "SUCCESS"
+        else:
+            message = ""
+            level = "WARNING"
         if ignored_count:
             message += (
                 f" Ignored {ignored_count} notification(s), which can not be rendered."
             )
-        self.message_user(request, message)
+        self.message_user(request, message, level=level)
 
     @admin.display(description="Process selected notifications for timerboard")
     def process_for_timerboard(self, request, queryset):
@@ -379,7 +414,8 @@ class OwnerAdmin(admin.ModelAdmin):
         return obj.has_default_pings_enabled
 
     def _ping_groups(self, obj):
-        return sorted([ping_group.name for ping_group in obj.ping_groups.all()])
+        ping_groups = [ping_group.name for ping_group in obj.ping_groups.all()]
+        return lines_sorted_html(ping_groups) if ping_groups else None
 
     @admin.display(ordering="corporation__corporation_name")
     def _corporation(self, obj):
@@ -392,9 +428,9 @@ class OwnerAdmin(admin.ModelAdmin):
         return None
 
     def _webhooks(self, obj):
-        names = sorted([webhook.name for webhook in obj.webhooks.all()])
+        names = [webhook.name for webhook in obj.webhooks.all()]
         if names:
-            return names
+            return lines_sorted_html(names)
         return format_html(
             '<span style="color: red">⚠ Notifications can not be sent, '
             "because there is no webhook configured for this owner.</span>"
@@ -494,7 +530,7 @@ class OwnerAdmin(admin.ModelAdmin):
         return self.readonly_fields
 
     inlines = (OwnerCharacterAdminInline,)
-    filter_horizontal = ("ping_groups",)
+    filter_horizontal = ("ping_groups", "webhooks")
     fieldsets = (
         (
             None,
@@ -640,7 +676,7 @@ class StructureTagAdmin(admin.ModelAdmin):
         return False if obj and not obj.is_user_managed else True
 
 
-class StructureAdminInline(admin.TabularInline):
+class StructureServicesAdminInline(admin.TabularInline):
     model = StructureService
 
     def has_add_permission(self, request, obj=None):
@@ -699,6 +735,23 @@ class OwnerAllianceFilter(admin.SimpleListFilter):
             return qs.filter(owner__corporation__alliance__alliance_id=self.value())
 
 
+class HasWebhooksListFilter(admin.SimpleListFilter):
+    title = "has webhooks"
+    parameter_name = "has_webhooks"
+
+    def lookups(self, request, model_admin):
+        return (
+            ("y", "yes"),
+            ("n", "no"),
+        )
+
+    def queryset(self, request, queryset):
+        if self.value() == "y":
+            return queryset.filter(webhooks__isnull=False)
+        if self.value() == "n":
+            return queryset.filter(webhooks__isnull=True)
+
+
 @admin.register(Structure)
 class StructureAdmin(admin.ModelAdmin):
     show_full_result_count = True
@@ -715,12 +768,21 @@ class StructureAdmin(admin.ModelAdmin):
         "eve_moon",
     )
     search_fields = [
+        "id",
         "name",
         "owner__corporation__corporation_name",
         "eve_solar_system__name",
     ]
     ordering = ["name"]
-    list_display = ("_name", "_owner", "_location", "_type", "_power_mode", "_tags")
+    list_display = (
+        "_name",
+        "_owner",
+        "_location",
+        "_type",
+        "_power_mode",
+        "_tags",
+        "_webhooks",
+    )
     list_filter = (
         OwnerCorporationsFilter,
         OwnerAllianceFilter,
@@ -733,13 +795,17 @@ class StructureAdmin(admin.ModelAdmin):
         ("eve_type__eve_group", admin.RelatedOnlyFieldListFilter),
         ("eve_type__eve_group__eve_category", admin.RelatedOnlyFieldListFilter),
         ("tags", admin.RelatedOnlyFieldListFilter),
+        HasWebhooksListFilter,
     )
 
     actions = ("add_default_tags", "remove_user_tags", "update_generated_tags")
 
+    def has_add_permission(self, request):
+        return False
+
     def get_queryset(self, request):
         qs = super().get_queryset(request)
-        return qs.prefetch_related("tags")
+        return qs.prefetch_related("tags", "webhooks")
 
     @admin.display(ordering="name")
     def _name(self, structure) -> str:
@@ -775,8 +841,9 @@ class StructureAdmin(admin.ModelAdmin):
     def _tags(self, structure) -> str:
         return sorted([tag.name for tag in structure.tags.all()])
 
-    def has_add_permission(self, request):
-        return False
+    def _webhooks(self, obj):
+        names = [webhook.name for webhook in obj.webhooks.all()]
+        return lines_sorted_html(names) if names else None
 
     @admin.display(description="Add default tags to selected structures")
     def add_default_tags(self, request, queryset):
@@ -820,11 +887,23 @@ class StructureAdmin(admin.ModelAdmin):
         [
             x.name
             for x in Structure._meta.get_fields()
-            if isinstance(x, models.fields.Field) and x.name not in ["tags"]
+            if isinstance(x, models.fields.Field) and x.name not in ["tags", "webhooks"]
         ]
     )
     fieldsets = (
-        (None, {"fields": ("name", "owner", "eve_solar_system", "eve_type", "tags")}),
+        (
+            None,
+            {
+                "fields": (
+                    "name",
+                    "owner",
+                    "eve_solar_system",
+                    "eve_type",
+                    "tags",
+                    "webhooks",
+                )
+            },
+        ),
         (
             "Status",
             {
@@ -875,7 +954,8 @@ class StructureAdmin(admin.ModelAdmin):
             },
         ),
     )
-    inlines = (StructureAdminInline,)
+    filter_horizontal = ("tags", "webhooks")
+    inlines = (StructureServicesAdminInline,)
 
     def formfield_for_manytomany(self, db_field, request, **kwargs):
         """only show custom tags in dropdown"""
@@ -908,28 +988,43 @@ class WebhookAdmin(admin.ModelAdmin):
 
     def get_queryset(self, request):
         qs = super().get_queryset(request)
-        return qs.prefetch_related("ping_groups", "owner_set", "owner_set__corporation")
+        return qs.prefetch_related(
+            "ping_groups",
+            "owners",
+            "owners__corporation",
+            Prefetch(
+                "structures",
+                queryset=Structure.objects.select_related(
+                    "eve_solar_system",
+                    "eve_type",
+                    "eve_type__eve_group",
+                    "owner",
+                    "owner__corporation",
+                ),
+            ),
+        )
 
+    @admin.display(boolean=True)
     def _default_pings(self, obj):
         return obj.has_default_pings_enabled
 
-    _default_pings.boolean = True
-
     def _ping_groups(self, obj):
         ping_groups = [ping_group.name for ping_group in obj.ping_groups.all()]
-        if not ping_groups:
-            return None
-        return sorted(ping_groups)
+        return lines_sorted_html(ping_groups) if ping_groups else None
 
-    @admin.display(description="Enabled for Owners")
+    @admin.display(description="Enabled for Owners/Structures")
     def _owners(self, obj):
-        owners = [str(owner) for owner in obj.owner_set.all()]
-        if not owners:
+        configurations = [str(owner) for owner in obj.owners.all()]
+        configurations += [
+            f"{structure.owner}: {structure}" for structure in obj.structures.all()
+        ]
+        if not configurations:
             return format_html(
                 '<b><span style="color: orange;">'
-                "⚠ Please add this webhook to an owner to enable it.</span></b>"
+                "⚠ Please add this webhook to an owner or structure to enable it."
+                "</span></b>"
             )
-        return sorted(owners)
+        return lines_sorted_html(configurations)
 
     def _is_default(self, obj):
         value = True if obj.is_default else None
