@@ -1316,7 +1316,7 @@ class FuelAlertConfig(BaseFuelAlertConfig):
     def relevant_webhooks() -> models.QuerySet:
         """Webhooks relevant for processing fuel notifications based on this config."""
         return (
-            Webhook.objects.filter(owner__isnull=False)
+            Webhook.objects.filter(owners__isnull=False)
             .filter(is_active=True)
             .filter(
                 Q(notification_types__contains=NotificationType.STRUCTURE_FUEL_ALERT)
@@ -1362,7 +1362,7 @@ class JumpFuelAlertConfig(BaseFuelAlertConfig):
     def relevant_webhooks() -> models.QuerySet:
         """Webhooks relevant for processing jump fuel notifications based on this config."""
         return Webhook.objects.filter(
-            owner__isnull=False,
+            owners__isnull=False,
             is_active=True,
             notification_types__contains=NotificationType.STRUCTURE_JUMP_FUEL_ALERT,
         )
